@@ -9,14 +9,14 @@ setClass("TDR",
              if (!slot(object, "dtime")) return("dtime cannot be missing")
          })
 
-setClass("TDRvel",
-         representation=representation("TDR", velocity="numeric"),
+setClass("TDRspeed",
+         representation=representation("TDR", speed="numeric"),
          contains="TDR",
          validity=function(object) {
-             vel.len <- length(slot(object, "velocity"))
+             speed.len <- length(slot(object, "speed"))
              tim.len <- length(slot(object, "time"))
-             if (vel.len != tim.len) {
-                 return("velocity and time have unequal lengths")
+             if (speed.len != tim.len) {
+                 return("speed and time have unequal lengths")
              }
          })
 
@@ -24,8 +24,8 @@ setClass("TDRcalibrate",
          representation=representation(tdr="TDR", gross.activity="list",
              dive.activity="data.frame", dive.phases="factor",
              land.threshold="numeric", sea.threshold="numeric",
-             dive.threshold="numeric", vel.calib.coefs="numeric"),
-         prototype=prototype(vel.calib.coefs=c(0, 1)),
+             dive.threshold="numeric", speed.calib.coefs="numeric"),
+         prototype=prototype(speed.calib.coefs=c(0, 1)),
          validity=function(object) {
              if (length(slot(object, "land.threshold")) > 1) {
                  return("land.threshold must be a single number")
@@ -36,8 +36,8 @@ setClass("TDRcalibrate",
              if (length(slot(object, "dive.threshold")) > 1) {
                  return("dive.threshold must be a single number")
              }
-             if (length(slot(object, "vel.calib.coefs")) != 2) {
-                 return("vel.calib.coefs must be a length-2 vector")
+             if (length(slot(object, "speed.calib.coefs")) != 2) {
+                 return("speed.calib.coefs must be a length-2 vector")
              }
          })
 
